Class: Aws::SnowDeviceManagement::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SnowDeviceManagement::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-snowdevicemanagement/client.rb
Overview
An API client for SnowDeviceManagement. To construct a client, you need to configure a :region and :credentials.
client = Aws::SnowDeviceManagement::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_task(params = {}) ⇒ Types::CancelTaskOutput
Sends a cancel request for a specified task.
-
#create_task(params = {}) ⇒ Types::CreateTaskOutput
Instructs one or more devices to start a task, such as unlocking or rebooting.
-
#describe_device(params = {}) ⇒ Types::DescribeDeviceOutput
Checks device-specific information, such as the device type, software version, IP addresses, and lock status.
-
#describe_device_ec2_instances(params = {}) ⇒ Types::DescribeDeviceEc2Output
Checks the current state of the Amazon EC2 instances.
-
#describe_execution(params = {}) ⇒ Types::DescribeExecutionOutput
Checks the status of a remote task running on one or more target devices.
-
#describe_task(params = {}) ⇒ Types::DescribeTaskOutput
Checks the metadata for a given task on a device.
-
#list_device_resources(params = {}) ⇒ Types::ListDeviceResourcesOutput
Returns a list of the Amazon Web Services resources available for a device.
-
#list_devices(params = {}) ⇒ Types::ListDevicesOutput
Returns a list of all devices on your Amazon Web Services account that have Amazon Web Services Snow Device Management enabled in the Amazon Web Services Region where the command is run.
-
#list_executions(params = {}) ⇒ Types::ListExecutionsOutput
Returns the status of tasks for one or more target devices.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns a list of tags for a managed device or task.
-
#list_tasks(params = {}) ⇒ Types::ListTasksOutput
Returns a list of tasks that can be filtered by state.
-
#tag_resource(params = {}) ⇒ Struct
Adds or replaces tags on a device or task.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a device or task.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1094 1095 1096 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 1094 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1097 1098 1099 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 1097 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 1067 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SnowDeviceManagement') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-snowdevicemanagement' context[:gem_version] = '1.49.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_task(params = {}) ⇒ Types::CancelTaskOutput
Sends a cancel request for a specified task. You can cancel a task only if it’s still in a QUEUED state. Tasks that are already running can’t be cancelled.
<note markdown=“1”> A task might still run if it’s processed from the queue before the CancelTask operation changes the task’s state.
</note>
510 511 512 513 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 510 def cancel_task(params = {}, = {}) req = build_request(:cancel_task, params) req.send_request() end |
#create_task(params = {}) ⇒ Types::CreateTaskOutput
Instructs one or more devices to start a task, such as unlocking or rebooting.
571 572 573 574 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 571 def create_task(params = {}, = {}) req = build_request(:create_task, params) req.send_request() end |
#describe_device(params = {}) ⇒ Types::DescribeDeviceOutput
Checks device-specific information, such as the device type, software version, IP addresses, and lock status.
635 636 637 638 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 635 def describe_device(params = {}, = {}) req = build_request(:describe_device, params) req.send_request() end |
#describe_device_ec2_instances(params = {}) ⇒ Types::DescribeDeviceEc2Output
Checks the current state of the Amazon EC2 instances. The output is similar to describeDevice, but the results are sourced from the device cache in the Amazon Web Services Cloud and include a subset of the available fields.
693 694 695 696 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 693 def describe_device_ec2_instances(params = {}, = {}) req = build_request(:describe_device_ec2_instances, params) req.send_request() end |
#describe_execution(params = {}) ⇒ Types::DescribeExecutionOutput
Checks the status of a remote task running on one or more target devices.
736 737 738 739 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 736 def describe_execution(params = {}, = {}) req = build_request(:describe_execution, params) req.send_request() end |
#describe_task(params = {}) ⇒ Types::DescribeTaskOutput
Checks the metadata for a given task on a device.
782 783 784 785 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 782 def describe_task(params = {}, = {}) req = build_request(:describe_task, params) req.send_request() end |
#list_device_resources(params = {}) ⇒ Types::ListDeviceResourcesOutput
Returns a list of the Amazon Web Services resources available for a device. Currently, Amazon EC2 instances are the only supported resource type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
831 832 833 834 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 831 def list_device_resources(params = {}, = {}) req = build_request(:list_device_resources, params) req.send_request() end |
#list_devices(params = {}) ⇒ Types::ListDevicesOutput
Returns a list of all devices on your Amazon Web Services account that have Amazon Web Services Snow Device Management enabled in the Amazon Web Services Region where the command is run.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
878 879 880 881 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 878 def list_devices(params = {}, = {}) req = build_request(:list_devices, params) req.send_request() end |
#list_executions(params = {}) ⇒ Types::ListExecutionsOutput
Returns the status of tasks for one or more target devices.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
926 927 928 929 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 926 def list_executions(params = {}, = {}) req = build_request(:list_executions, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns a list of tags for a managed device or task.
955 956 957 958 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 955 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_tasks(params = {}) ⇒ Types::ListTasksOutput
Returns a list of tasks that can be filtered by state.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1000 1001 1002 1003 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 1000 def list_tasks(params = {}, = {}) req = build_request(:list_tasks, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds or replaces tags on a device or task.
1030 1031 1032 1033 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 1030 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a device or task.
1058 1059 1060 1061 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 1058 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1087 1088 1089 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 1087 def waiter_names [] end |