Class: Aws::SnowDeviceManagement::Types::DescribeDeviceOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-snowdevicemanagement/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#associated_with_job ⇒ String

The ID of the job used when ordering the device.

Returns:

  • (String)


278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/aws-sdk-snowdevicemanagement/types.rb', line 278

class DescribeDeviceOutput < Struct.new(
  :associated_with_job,
  :device_capacities,
  :device_state,
  :device_type,
  :last_reached_out_at,
  :last_updated_at,
  :managed_device_arn,
  :managed_device_id,
  :physical_network_interfaces,
  :software,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#device_capacities ⇒ Array<Types::Capacity>

The hardware specifications of the device.

Returns:



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/aws-sdk-snowdevicemanagement/types.rb', line 278

class DescribeDeviceOutput < Struct.new(
  :associated_with_job,
  :device_capacities,
  :device_state,
  :device_type,
  :last_reached_out_at,
  :last_updated_at,
  :managed_device_arn,
  :managed_device_id,
  :physical_network_interfaces,
  :software,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#device_state ⇒ String

The current state of the device.

Returns:

  • (String)


278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/aws-sdk-snowdevicemanagement/types.rb', line 278

class DescribeDeviceOutput < Struct.new(
  :associated_with_job,
  :device_capacities,
  :device_state,
  :device_type,
  :last_reached_out_at,
  :last_updated_at,
  :managed_device_arn,
  :managed_device_id,
  :physical_network_interfaces,
  :software,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#device_type ⇒ String

The type of Amazon Web Services Snow Family device.

Returns:

  • (String)


278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/aws-sdk-snowdevicemanagement/types.rb', line 278

class DescribeDeviceOutput < Struct.new(
  :associated_with_job,
  :device_capacities,
  :device_state,
  :device_type,
  :last_reached_out_at,
  :last_updated_at,
  :managed_device_arn,
  :managed_device_id,
  :physical_network_interfaces,
  :software,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_reached_out_at ⇒ Time

When the device last contacted the Amazon Web Services Cloud. Indicates that the device is online.

Returns:

  • (Time)


278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/aws-sdk-snowdevicemanagement/types.rb', line 278

class DescribeDeviceOutput < Struct.new(
  :associated_with_job,
  :device_capacities,
  :device_state,
  :device_type,
  :last_reached_out_at,
  :last_updated_at,
  :managed_device_arn,
  :managed_device_id,
  :physical_network_interfaces,
  :software,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_at ⇒ Time

When the device last pushed an update to the Amazon Web Services Cloud. Indicates when the device cache was refreshed.

Returns:

  • (Time)


278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/aws-sdk-snowdevicemanagement/types.rb', line 278

class DescribeDeviceOutput < Struct.new(
  :associated_with_job,
  :device_capacities,
  :device_state,
  :device_type,
  :last_reached_out_at,
  :last_updated_at,
  :managed_device_arn,
  :managed_device_id,
  :physical_network_interfaces,
  :software,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#managed_device_arn ⇒ String

The Amazon Resource Name (ARN) of the device.

Returns:

  • (String)


278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/aws-sdk-snowdevicemanagement/types.rb', line 278

class DescribeDeviceOutput < Struct.new(
  :associated_with_job,
  :device_capacities,
  :device_state,
  :device_type,
  :last_reached_out_at,
  :last_updated_at,
  :managed_device_arn,
  :managed_device_id,
  :physical_network_interfaces,
  :software,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#managed_device_id ⇒ String

The ID of the device that you checked the information for.

Returns:

  • (String)


278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/aws-sdk-snowdevicemanagement/types.rb', line 278

class DescribeDeviceOutput < Struct.new(
  :associated_with_job,
  :device_capacities,
  :device_state,
  :device_type,
  :last_reached_out_at,
  :last_updated_at,
  :managed_device_arn,
  :managed_device_id,
  :physical_network_interfaces,
  :software,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#physical_network_interfaces ⇒ Array<Types::PhysicalNetworkInterface>

The network interfaces available on the device.



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/aws-sdk-snowdevicemanagement/types.rb', line 278

class DescribeDeviceOutput < Struct.new(
  :associated_with_job,
  :device_capacities,
  :device_state,
  :device_type,
  :last_reached_out_at,
  :last_updated_at,
  :managed_device_arn,
  :managed_device_id,
  :physical_network_interfaces,
  :software,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#software ⇒ Types::SoftwareInformation

The software installed on the device.



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/aws-sdk-snowdevicemanagement/types.rb', line 278

class DescribeDeviceOutput < Struct.new(
  :associated_with_job,
  :device_capacities,
  :device_state,
  :device_type,
  :last_reached_out_at,
  :last_updated_at,
  :managed_device_arn,
  :managed_device_id,
  :physical_network_interfaces,
  :software,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

Optional metadata that you assign to a resource. You can use tags to categorize a resource in different ways, such as by purpose, owner, or environment.

Returns:

  • (Hash<String,String>)


278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/aws-sdk-snowdevicemanagement/types.rb', line 278

class DescribeDeviceOutput < Struct.new(
  :associated_with_job,
  :device_capacities,
  :device_state,
  :device_type,
  :last_reached_out_at,
  :last_updated_at,
  :managed_device_arn,
  :managed_device_id,
  :physical_network_interfaces,
  :software,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end