Class: Aws::SnowDeviceManagement::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SnowDeviceManagement::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-snowdevicemanagement/client.rb,
sig/client.rbs
Overview
An API client for SnowDeviceManagement. To construct a client, you need to configure a :region and :credentials.
client = Aws::SnowDeviceManagement::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CancelTaskResponseSuccess, _CreateTaskResponseSuccess, _DescribeDeviceEc2InstancesResponseSuccess, _DescribeDeviceResponseSuccess, _DescribeExecutionResponseSuccess, _DescribeTaskResponseSuccess, _ListDeviceResourcesResponseSuccess, _ListDevicesResponseSuccess, _ListExecutionsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTasksResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_task(params = {}) ⇒ Types::CancelTaskOutput
Sends a cancel request for a specified task.
-
#create_task(params = {}) ⇒ Types::CreateTaskOutput
Instructs one or more devices to start a task, such as unlocking or rebooting.
-
#describe_device(params = {}) ⇒ Types::DescribeDeviceOutput
Checks device-specific information, such as the device type, software version, IP addresses, and lock status.
-
#describe_device_ec2_instances(params = {}) ⇒ Types::DescribeDeviceEc2Output
Checks the current state of the Amazon EC2 instances.
-
#describe_execution(params = {}) ⇒ Types::DescribeExecutionOutput
Checks the status of a remote task running on one or more target devices.
-
#describe_task(params = {}) ⇒ Types::DescribeTaskOutput
Checks the metadata for a given task on a device.
-
#list_device_resources(params = {}) ⇒ Types::ListDeviceResourcesOutput
Returns a list of the Amazon Web Services resources available for a device.
-
#list_devices(params = {}) ⇒ Types::ListDevicesOutput
Returns a list of all devices on your Amazon Web Services account that have Amazon Web Services Snow Device Management enabled in the Amazon Web Services Region where the command is run.
-
#list_executions(params = {}) ⇒ Types::ListExecutionsOutput
Returns the status of tasks for one or more target devices.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns a list of tags for a managed device or task.
-
#list_tasks(params = {}) ⇒ Types::ListTasksOutput
Returns a list of tasks that can be filtered by state.
-
#tag_resource(params = {}) ⇒ Struct
Adds or replaces tags on a device or task.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a device or task.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1092 1093 1094 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 1092 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1095 1096 1097 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 1095 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 1065 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SnowDeviceManagement') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-snowdevicemanagement' context[:gem_version] = '1.54.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_task(params = {}) ⇒ Types::CancelTaskOutput
Sends a cancel request for a specified task. You can cancel a task
only if it's still in a QUEUED state. Tasks that are already
running can't be cancelled.
CancelTask operation changes the task's state.
86 |
# File 'sig/client.rbs', line 86
def cancel_task: (
|
#create_task(params = {}) ⇒ Types::CreateTaskOutput
Instructs one or more devices to start a task, such as unlocking or rebooting.
97 |
# File 'sig/client.rbs', line 97
def create_task: (
|
#describe_device(params = {}) ⇒ Types::DescribeDeviceOutput
Checks device-specific information, such as the device type, software version, IP addresses, and lock status.
126 |
# File 'sig/client.rbs', line 126
def describe_device: (
|
#describe_device_ec2_instances(params = {}) ⇒ Types::DescribeDeviceEc2Output
Checks the current state of the Amazon EC2 instances. The output is
similar to describeDevice, but the results are sourced from the
device cache in the Amazon Web Services Cloud and include a subset of
the available fields.
136 |
# File 'sig/client.rbs', line 136
def describe_device_ec2_instances: (
|
#describe_execution(params = {}) ⇒ Types::DescribeExecutionOutput
Checks the status of a remote task running on one or more target devices.
152 |
# File 'sig/client.rbs', line 152
def describe_execution: (
|
#describe_task(params = {}) ⇒ Types::DescribeTaskOutput
Checks the metadata for a given task on a device.
171 |
# File 'sig/client.rbs', line 171
def describe_task: (
|
#list_device_resources(params = {}) ⇒ Types::ListDeviceResourcesOutput
Returns a list of the Amazon Web Services resources available for a device. Currently, Amazon EC2 instances are the only supported resource type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
182 |
# File 'sig/client.rbs', line 182
def list_device_resources: (
|
#list_devices(params = {}) ⇒ Types::ListDevicesOutput
Returns a list of all devices on your Amazon Web Services account that have Amazon Web Services Snow Device Management enabled in the Amazon Web Services Region where the command is run.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
196 |
# File 'sig/client.rbs', line 196
def list_devices: (
|
#list_executions(params = {}) ⇒ Types::ListExecutionsOutput
Returns the status of tasks for one or more target devices.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
209 |
# File 'sig/client.rbs', line 209
def list_executions: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns a list of tags for a managed device or task.
222 |
# File 'sig/client.rbs', line 222
def list_tags_for_resource: (
|
#list_tasks(params = {}) ⇒ Types::ListTasksOutput
Returns a list of tasks that can be filtered by state.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
233 |
# File 'sig/client.rbs', line 233
def list_tasks: (
|
#tag_resource(params = {}) ⇒ Struct
Adds or replaces tags on a device or task.
241 |
# File 'sig/client.rbs', line 241
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a device or task.
248 |
# File 'sig/client.rbs', line 248
def untag_resource: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1085 1086 1087 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 1085 def waiter_names [] end |