Class: Aws::SnowDeviceManagement::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SnowDeviceManagement::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-snowdevicemanagement/client.rb
Overview
An API client for SnowDeviceManagement. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SnowDeviceManagement::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_task(params = {}) ⇒ Types::CancelTaskOutput
Sends a cancel request for a specified task.
-
#create_task(params = {}) ⇒ Types::CreateTaskOutput
Instructs one or more devices to start a task, such as unlocking or rebooting.
-
#describe_device(params = {}) ⇒ Types::DescribeDeviceOutput
Checks device-specific information, such as the device type, software version, IP addresses, and lock status.
-
#describe_device_ec2_instances(params = {}) ⇒ Types::DescribeDeviceEc2Output
Checks the current state of the Amazon EC2 instances.
-
#describe_execution(params = {}) ⇒ Types::DescribeExecutionOutput
Checks the status of a remote task running on one or more target devices.
-
#describe_task(params = {}) ⇒ Types::DescribeTaskOutput
Checks the metadata for a given task on a device.
-
#list_device_resources(params = {}) ⇒ Types::ListDeviceResourcesOutput
Returns a list of the Amazon Web Services resources available for a device.
-
#list_devices(params = {}) ⇒ Types::ListDevicesOutput
Returns a list of all devices on your Amazon Web Services account that have Amazon Web Services Snow Device Management enabled in the Amazon Web Services Region where the command is run.
-
#list_executions(params = {}) ⇒ Types::ListExecutionsOutput
Returns the status of tasks for one or more target devices.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns a list of tags for a managed device or task.
-
#list_tasks(params = {}) ⇒ Types::ListTasksOutput
Returns a list of tasks that can be filtered by state.
-
#tag_resource(params = {}) ⇒ Struct
Adds or replaces tags on a device or task.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a device or task.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1092 1093 1094 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 1092 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1095 1096 1097 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 1095 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 1065 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SnowDeviceManagement') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-snowdevicemanagement' context[:gem_version] = '1.52.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_task(params = {}) ⇒ Types::CancelTaskOutput
Sends a cancel request for a specified task. You can cancel a task only if it’s still in a ‘QUEUED` state. Tasks that are already running can’t be cancelled.
<note markdown=“1”> A task might still run if it’s processed from the queue before the ‘CancelTask` operation changes the task’s state.
</note>
508 509 510 511 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 508 def cancel_task(params = {}, = {}) req = build_request(:cancel_task, params) req.send_request() end |
#create_task(params = {}) ⇒ Types::CreateTaskOutput
Instructs one or more devices to start a task, such as unlocking or rebooting.
569 570 571 572 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 569 def create_task(params = {}, = {}) req = build_request(:create_task, params) req.send_request() end |
#describe_device(params = {}) ⇒ Types::DescribeDeviceOutput
Checks device-specific information, such as the device type, software version, IP addresses, and lock status.
633 634 635 636 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 633 def describe_device(params = {}, = {}) req = build_request(:describe_device, params) req.send_request() end |
#describe_device_ec2_instances(params = {}) ⇒ Types::DescribeDeviceEc2Output
Checks the current state of the Amazon EC2 instances. The output is similar to ‘describeDevice`, but the results are sourced from the device cache in the Amazon Web Services Cloud and include a subset of the available fields.
691 692 693 694 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 691 def describe_device_ec2_instances(params = {}, = {}) req = build_request(:describe_device_ec2_instances, params) req.send_request() end |
#describe_execution(params = {}) ⇒ Types::DescribeExecutionOutput
Checks the status of a remote task running on one or more target devices.
734 735 736 737 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 734 def describe_execution(params = {}, = {}) req = build_request(:describe_execution, params) req.send_request() end |
#describe_task(params = {}) ⇒ Types::DescribeTaskOutput
Checks the metadata for a given task on a device.
780 781 782 783 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 780 def describe_task(params = {}, = {}) req = build_request(:describe_task, params) req.send_request() end |
#list_device_resources(params = {}) ⇒ Types::ListDeviceResourcesOutput
Returns a list of the Amazon Web Services resources available for a device. Currently, Amazon EC2 instances are the only supported resource type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
829 830 831 832 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 829 def list_device_resources(params = {}, = {}) req = build_request(:list_device_resources, params) req.send_request() end |
#list_devices(params = {}) ⇒ Types::ListDevicesOutput
Returns a list of all devices on your Amazon Web Services account that have Amazon Web Services Snow Device Management enabled in the Amazon Web Services Region where the command is run.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
876 877 878 879 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 876 def list_devices(params = {}, = {}) req = build_request(:list_devices, params) req.send_request() end |
#list_executions(params = {}) ⇒ Types::ListExecutionsOutput
Returns the status of tasks for one or more target devices.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
924 925 926 927 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 924 def list_executions(params = {}, = {}) req = build_request(:list_executions, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns a list of tags for a managed device or task.
953 954 955 956 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 953 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_tasks(params = {}) ⇒ Types::ListTasksOutput
Returns a list of tasks that can be filtered by state.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
998 999 1000 1001 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 998 def list_tasks(params = {}, = {}) req = build_request(:list_tasks, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds or replaces tags on a device or task.
1028 1029 1030 1031 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 1028 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a device or task.
1056 1057 1058 1059 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 1056 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1085 1086 1087 |
# File 'lib/aws-sdk-snowdevicemanagement/client.rb', line 1085 def waiter_names [] end |